@@ -1,6 +1,5 @@
 import datetime
 import json
-import random
 
 from django import forms
 from django.core.exceptions import PermissionDenied
@@ -20,7 +19,7 @@ from wagtail.admin.views.reports import ReportView
 from wagtail.core.models import Page, PAGE_MODEL_CLASSES, UserPagePermissionsProxy
 
 from .models import AbTest
-from .events import EVENT_TYPES
+from .events import get_event_types
 
 
 class CreateAbTestForm(forms.ModelForm):
@@ -32,7 +31,7 @@ class CreateAbTestForm(forms.ModelForm):
 
         self.fields['goal_event'].choices = [
             (slug, goal.name)
-            for slug, goal in EVENT_TYPES.items()
+            for slug, goal in get_event_types().items()
         ]
 
     def save(self, page, variant_revision, user):
@@ -132,7 +131,7 @@ def add_form(request, page_id):
                         'slug': slug,
                         'name': event_type.name,
                     }
-                    for slug, event_type in EVENT_TYPES.items()
+                    for slug, event_type in get_event_types().items()
                     if event_type.can_be_triggered_on_page_type(page_type)
                 ]
                 for page_type in PAGE_MODEL_CLASSES
@@ -402,25 +401,6 @@ def compare_draft(request, page_id):
     })
 
 
-# TEMPORARY
-def add_test_participants(request, ab_test_id):
-    ab_test = get_object_or_404(AbTest, id=ab_test_id)
-
-    for i in range(int(ab_test.sample_size / 10)):
-        ab_test.add_participant()
-
-    return redirect('wagtailadmin_pages:edit', ab_test.page_id)
-
-
-def add_test_conversions(request, ab_test_id, version):
-    ab_test = get_object_or_404(AbTest, id=ab_test_id)
-
-    for i in range(int(ab_test.sample_size / 10)):
-        ab_test.log_conversion(version, time=timezone.now() - datetime.timedelta(days=random.randint(1, 20), hours=random.randint(0, 24)))
-
-    return redirect('wagtailadmin_pages:edit', ab_test.page_id)
-
-
 class SearchPageTitleFilter(django_filters.CharFilter):
     def filter(self, qs, value):
         if value in EMPTY_VALUES:
